<?php

namespace Buyesrfolio\LeadTask\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Buyesrfolio\LeadTask\Http\Requests\LeadTaskRequest;
use Buyesrfolio\LeadTask\Interfaces\LeadTaskRepositoryInterface;
use Buyesrfolio\LeadTask\Models\LeadTask;

/**
 * Resource controller class for lead_task.
 */
class LeadTaskResourceController extends BaseController
{

    /**
     * Initialize lead_task resource controller.
     *
     * @param type LeadTaskRepositoryInterface $lead_task
     *
     * @return null
     */
    public function __construct(LeadTaskRepositoryInterface $lead_task)
    {
        parent::__construct();
        $this->repository = $lead_task;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Buyesrfolio\LeadTask\Repositories\Criteria\LeadTaskResourceCriteria::class);
    }

    /**
     * Display a list of lead_task.
     *
     * @return Response
     */
    public function index(LeadTaskRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Buyesrfolio\LeadTask\Repositories\Presenter\LeadTaskPresenter::class)
                ->$function();
        }

        $lead_tasks = $this->repository->paginate();

        return $this->response->setMetaTitle(trans('lead_task::lead_task.names'))
            ->view('lead_task::lead_task.index', true)
            ->data(compact('lead_tasks', 'view'))
            ->output();
    }

    /**
     * Display lead_task.
     *
     * @param Request $request
     * @param Model   $lead_task
     *
     * @return Response
     */
    public function show(LeadTaskRequest $request, LeadTask $lead_task)
    {

        if ($lead_task->exists) {
            $view = 'lead_task::lead_task.show';
        } else {
            $view = 'lead_task::lead_task.new';
        }

        return $this->response->setMetaTitle(trans('app.view') . ' ' . trans('lead_task::lead_task.name'))
            ->data(compact('lead_task'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new lead_task.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(LeadTaskRequest $request)
    {

        $lead_task = $this->repository->newInstance([]);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('lead_task::lead_task.name')) 
            ->view('lead_task::lead_task.create', true) 
            ->data(compact('lead_task'))
            ->output();
    }

    /**
     * Create new lead_task.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(LeadTaskRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $lead_task                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('lead_task::lead_task.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('lead_task/lead_task/' . $lead_task->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/lead_task/lead_task'))
                ->redirect();
        }

    }

    /**
     * Show lead_task for editing.
     *
     * @param Request $request
     * @param Model   $lead_task
     *
     * @return Response
     */
    public function edit(LeadTaskRequest $request, LeadTask $lead_task)
    {
        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('lead_task::lead_task.name'))
            ->view('lead_task::lead_task.edit', true)
            ->data(compact('lead_task'))
            ->output();
    }

    /**
     * Update the lead_task.
     *
     * @param Request $request
     * @param Model   $lead_task
     *
     * @return Response
     */
    public function update(LeadTaskRequest $request, LeadTask $lead_task)
    {
        try {
            $attributes = $request->all();

            $lead_task->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('lead_task::lead_task.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('lead_task/lead_task/' . $lead_task->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('lead_task/lead_task/' . $lead_task->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the lead_task.
     *
     * @param Model   $lead_task
     *
     * @return Response
     */
    public function destroy(LeadTaskRequest $request, LeadTask $lead_task)
    {
        try {

            $lead_task->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('lead_task::lead_task.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('lead_task/lead_task/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('lead_task/lead_task/' . $lead_task->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple lead_task.
     *
     * @param Model   $lead_task
     *
     * @return Response
     */
    public function delete(LeadTaskRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('lead_task::lead_task.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('lead_task/lead_task'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/lead_task/lead_task'))
                ->redirect();
        }

    }

    /**
     * Restore deleted lead_tasks.
     *
     * @param Model   $lead_task
     *
     * @return Response
     */
    public function restore(LeadTaskRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('lead_task::lead_task.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/lead_task/lead_task'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/lead_task/lead_task/'))
                ->redirect();
        }

    }

}
